;+
; NAME:
;      EXTRACTFUNC
;
; PURPOSE:
;      A function which extracts the optimal spectrum from a vector
;
; CALLING SEQUENCE:
;      Result = EXTRACTFUNC (XVALS, DATAV, VARV, PROFV, FOO, OPVAR=Opvar)
;
; INPUTS:
;      XVALS: The x values for the data
;      DATAV: The sky subtracted data vector
;      VARV:  The variance vector
;      PROFV: The profile vector
;
; OUTPUTS:
;      OPVAR: The variance of the optimal spectrum
;      Returns the optimal extraction
;
; MODIFICATION HISTORY:
;      Written by:    John Dermody, 22 Sep 2003
;
;-

function extractfunc, xvals, datav, varv, profv, eval, coeffv, opvar

gl = where(profv ne 0.)
denom = total( (profv[gl] * profv[gl]) / varv[gl]) ; avoid recalc
opt   = total( (profv[gl] * datav[gl]) / varv[gl]) / denom
opvar = total(  profv[gl] ) / denom

return, opt
end
