;+
; NAME:
;      POLYFUNC
;
; PURPOSE:
;      Function for fiting the data using a polynomial fit
;
; CATEGORY:
;      Optspecextr
;
; CALLING SEQUENCE:
;      Result = POLYFUNC (XVals, Datav, Varv, Specv, Deg, Coeff)
;
; INPUTS:
;      XVals: The indicies of the datav
;      Datav: The data vector to fit, must be same size as xvals
;      Varv:  The variance vector
;      Specv: The spectrum vector
;      Deg:   The degree of fit
;      Coeff: The coefficiants of the fit
;
; OUTPUTS:
;      The estimated spectrum
;
; OPTIONAL OUTPUTS:
;      Coeff = Will contain the coefficients of the fit
;
; MODIFICATION HISTORY:
;
;       Thu Dec 18 22:58:02 2003, John Dermody
;
;		If eval is set then evaluate Coeff.  Cleaned and Documented.
;
;       Sun Oct 19 17:26:22 2003, John Dermody
;
;		Created.  Check for locations inwhich variance equals
;		0, then use polyfit to evaluate other points.
;
;-

function POLYFUNC, xvals, datav, varv, specv, eval, coeffv, deg

if (eval eq 1) then begin
  fiteval = polyeval(coeffv, xvals)
  zl = where(varv eq 0.)
  if (zl ne [-1]) then fiteval[zl] = (datav / specv)
  return, fiteval
endif

nz = where(varv ne 0.)
est = datav / specv
if (nz ne [-1]) then begin
    m_errors = varv / specv ^ 2 > 1.e-6
    coeffv = poly_fit(xvals, datav/specv, deg, /double, $
                     yfit=estz, measure_errors=m_errors)
    est[nz] = estz[nz]
endif

return, est
end
