;+
; NAME:
;   RECVECT
;
;
; PURPOSE:
;   Uses spline interpolation to estimate bad rows from good ones
;
;
; CATEGORY:
;   Opspecextr routine
;
;
; CALLING SEQUENCE:
;   Image = RECVECT(Image, errvect, plottype=plottype)
;
;
; INPUTS:
;   Image:   The 2D estimated image
;   Errvect: A 1D mask of y values for bad rows
;
;
; KEYWORD PARAMETERS:
;   Plottype: if plottype eq 1 then shade surface the adjustment
;
;
; OUTPUTS:
;   The image with bad vectors splined from good rows
;
;
; MODIFICATION HISTORY:
;
;       Wed Dec 3 15:22:31 2003, John Dermody
;		Created
;
;       Wed Dec 10 00:48:56 2003, John Dermody
;               Ok, spline needs atleast three good vectors, so check
;               for that
;
;       Thu Dec 18 21:48:44 2003, John Dermody
;               Added in surface plots
;-


function RECVECT, image, errvect, plottype=plottype

ry = where(errvect eq 0) ; rows to be recovered
gy = where(errvect eq 1) ; good rows to use
nx = (size(image))[1]
ny = (size(image))[2]
nimage = image
if (n_elements(gy) lt 3) then begin
  nimage[*] = 0
endif else if (ry ne [-1]) then begin
  for i = 0, nx - 1 do begin
    nimage[i, ry] = spline(gy, image[i, gy], ry)
    if (plottype eq 1) then surface, nimage
  endfor
endif


return, nimage
end
